# coding: utf-8

"""
    ESnet implementation of the IRI api

     A simple implementation of the IRI facility API using python and the fastApi library.  For more information, see: [https://iri.science/](https://iri.science/)  <img src=\"https://iri.science/images/doe-icon-old.png\" height=50 /> 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from esnet_iri.models.job_status import JobStatus

class TestJobStatus(unittest.TestCase):
    """JobStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> JobStatus:
        """Test JobStatus
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `JobStatus`
        """
        model = JobStatus()
        if include_optional:
            return JobStatus(
                state = 'new',
                time = 1.337,
                message = '',
                exit_code = 56,
                meta_data = { }
            )
        else:
            return JobStatus(
                state = 'new',
        )
        """

    def testJobStatus(self):
        """Test JobStatus"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ESnet implementation of the IRI api

     A simple implementation of the IRI facility API using python and the fastApi library.  For more information, see: [https://iri.science/](https://iri.science/)  <img src=\"https://iri.science/images/doe-icon-old.png\" height=50 /> 

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from esnet_iri.api.facility_api import FacilityApi


class TestFacilityApi(unittest.TestCase):
    """FacilityApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FacilityApi()

    def tearDown(self) -> None:
        pass

    def test_get_facility(self) -> None:
        """Test case for get_facility

        Get Facility
        """
        pass

    def test_get_site(self) -> None:
        """Test case for get_site

        Get Site
        """
        pass

    def test_get_sites(self) -> None:
        """Test case for get_sites

        List Sites
        """
        pass


if __name__ == '__main__':
    unittest.main()
